==> amarok-2.8.0.tar.xz: amarok-2.8.0/src/widgets/LineEdit.cpp <==
/****************************************************************************************
 * Copyright (c) 2009 Seb Ruiz <ruiz@kde.org>                                           *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "LineEdit.h"

#include <QKeyEvent>

namespace Amarok
{

LineEdit::LineEdit( QWidget *parent )
   : KLineEdit( parent )
{
}

void LineEdit::keyPressEvent( QKeyEvent *event )
{
    if( event->key() == Qt::Key_Escape )
    {
        event->accept();
        clear();
        return;
    }
    else if( event->key() == Qt::Key_Down )
    {
        event->accept();
        emit downPressed();
        return;
    }
    else if ( event->key() == Qt::Key_Up )
    {
        event->accept();
        emit upPressed();
        return;
    }
    KLineEdit::keyPressEvent( event );
}

}

#include "LineEdit.moc"

==> amarok_3.3.1.orig.tar.xz: amarok-3.3.1/src/widgets/LineEdit.cpp <==
/****************************************************************************************
 * Copyright (c) 2009 Seb Ruiz <ruiz@kde.org>                                           *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "LineEdit.h"

#include <QKeyEvent>

namespace Amarok
{

LineEdit::LineEdit( QWidget *parent )
   : QLineEdit( parent )
{
}

void LineEdit::keyPressEvent( QKeyEvent *event )
{
    if( event->key() == Qt::Key_Escape )
    {
        event->accept();
        clear();
        return;
    }
    else if( event->key() == Qt::Key_Down )
    {
        event->accept();
        Q_EMIT downPressed();
        return;
    }
    else if ( event->key() == Qt::Key_Up )
    {
        event->accept();
        Q_EMIT upPressed();
        return;
    }
    QLineEdit::keyPressEvent( event );
}

}
